@@ -21,6 +21,9 @@
 #include <lager/lenses.hpp>
 #include <lager/lenses/tuple.hpp>
 
+#include <zug/transducer/filter.hpp>
+#include <zug/transducer/map.hpp>
+
 #include <boost/fusion/include/adapt_struct.hpp>
 #include <boost/fusion/include/comparison.hpp>
 
@@ -45,7 +48,7 @@ TEST_CASE("out, construction_and_assignment_from_temporary")
     writer<int> out1;
     // Access to uninitialized writer should throw an exception
     REQUIRE_THROWS(out1.set(42));
-    REQUIRE_THROWS(out1.update([](auto){ return 42;}));
+    REQUIRE_THROWS(out1.update([](auto) { return 42; }));
     out1 = make_state(0);
     writer<int> out2{make_state(0)};
 }
@@ -56,7 +59,7 @@ TEST_CASE("inout, construction_and_assignment_from_temporary")
     // Access to uninitialized cursor should throw an exception
     REQUIRE_THROWS(inout1.get());
     REQUIRE_THROWS(inout1.set(42));
-    REQUIRE_THROWS(inout1.update([](auto){ return 42;}));
+    REQUIRE_THROWS(inout1.update([](auto) { return 42; }));
     inout1 = make_state(0);
     cursor<int> inout2{make_state(0)};
 }
@@ -219,10 +222,77 @@ TEST_CASE("lenses over with expression")
 
     person_data.set(person{{}, "old name", {}});
 
-    cursor<std::string> name = with(person_data[&person::name], person_data[&person::birthday]).zoom(lenses::first);
+    cursor<std::string> name =
+        with(person_data[&person::name], person_data[&person::birthday])
+            .zoom(lenses::first);
 
     name.set("new name");
 
     CHECK(person_data->name == "new name");
     CHECK(name.get() == "new name");
 }
+
+struct Foo;
+struct Bar
+{
+    lager::reader<Foo> foo;
+    reader<Foo> get_reader() const;
+};
+struct Baz
+{
+    Baz(const lager::reader<Foo>& r);
+};
+
+TEST_CASE("forward declare a reader value")
+{
+    auto bar = Bar();
+    auto baz = Baz(bar.get_reader());
+    (void) bar;
+    (void) baz;
+}
+
+struct Foo
+{};
+
+lager::reader<Foo> Bar::get_reader() const
+{
+    return lager::make_constant(Foo());
+}
+
+Baz::Baz(const lager::reader<Foo>&) {}
+
+TEST_CASE("watch filtered xform of optional ints | update default value")
+{
+    state<std::optional<int>> state;
+    REQUIRE(state.get() == std::nullopt);
+
+    lager::reader<int> reader =
+        state.xform(zug::filter([](auto opt) { return opt.has_value(); }) |
+                    zug::map([](auto opt) { return *opt; }));
+
+    int called{};
+    watch(reader, [&](auto) { ++called; });
+
+    state.set(0);
+    commit(state);
+    REQUIRE(state.get() == 0);
+    CHECK(called == 1);
+}
+
+TEST_CASE("watch filtered xform of optional strings | update default value")
+{
+    state<std::optional<std::string>> state;
+    REQUIRE(state.get() == std::nullopt);
+
+    lager::reader<std::string> reader =
+        state.xform(zug::filter([](auto opt) { return opt.has_value(); }) |
+                    zug::map([](auto opt) { return *opt; }));
+
+    int called{};
+    watch(reader, [&](auto) { ++called; });
+
+    state.set("");
+    commit(state);
+    REQUIRE(state.get() == "");
+    CHECK(called == 1);
+}
